@@ -1,5 +1,5 @@
 dae.nonspecific.I <-
-function(zpre,zpost,mmat,componentname,cnames,cnamesie,emat,vmat,icol,iecol,gls)
+function(zpre,zpost,mmat,componentname,cnames,cnamesie,emat,vmat,icol,iecol,fixedgls,dmeopt)
 # dae.nonspecific.I() - expectations for a nonspecific component
 #             zpre,zposr are zi or zm or zc
 #             special case with no rel matrix
@@ -10,7 +10,7 @@ function(zpre,zpost,mmat,componentname,cnames,cnamesie,emat,vmat,icol,iecol,gls)
 #   zaz <- matrix(0,nrows(emat),nrows(emat)
     zaz <- nszpre %*% t(nszpost)
     emat[,icol] <- as.vector(mmat %*% zaz %*% mmat) # one col of W matrix
-    if(gls) {
+    if(fixedgls | dmeopt == "fgls") {
       vmat[,icol] <- as.vector(zaz) # one col of V matrix
     }
     cnames[icol] <- componentname # name for this col
