@@ -1,5 +1,5 @@
 dae.nonspecific.S <-
-function(zpre1,zpost1,zpre2,zpost2,zop,mmat,componentname,cnames,cnamesie,emat,vmat,icol,iecol,gls)
+function(zpre1,zpost1,zpre2,zpost2,zop,mmat,componentname,cnames,cnamesie,emat,vmat,icol,iecol,fixedgls,dmeopt)
 # dae.nonspecific.S() - expectations for a nonspecific component
 #             zpre,zposr are zi or zm or zc
 #             special case with two expectations anded together
@@ -13,7 +13,7 @@ function(zpre1,zpost1,zpre2,zpost2,zop,mmat,componentname,cnames,cnamesie,emat,v
 #   zaz <- matrix(0,nrows(emat),nrows(emat)
     zaz <- eval(parse(text=paste("(nszpre1 %*% t(nszpost1))", zop, " (nszpre2 %*% t(nszpost2))"," + 0",sep="")))
     emat[,icol] <- as.vector(mmat %*% zaz %*% mmat) # one col of W matrix
-    if(gls) {
+    if(fixedgls | dmeopt == "fgls") {
       vmat[,icol] <- as.vector(zaz) # one col of V matrix
     }
     cnames[icol] <- componentname # name for this col
